@@ -1,20 +1,19 @@
 package Juju::Util;
-$Juju::Util::VERSION = '2.0';
+BEGIN {
+  $Juju::Util::AUTHORITY = 'cpan:ADAMJS';
+}
+$Juju::Util::VERSION = '2.001_1';
 # ABSTRACT: helper methods for Juju
 
 
-use strict;
-use warnings;
+use Moose;
 use HTTP::Tiny;
 use JSON::PP;
-use Method::Signatures;
-use Moo;
-use namespace::clean;
-
-has series => (is => 'ro', default => sub { qr/precise|trusty|utopic/ });
+use Function::Parameters;
+use namespace::autoclean;
 
 
-method query_cs($charm, $series = "trusty") {
+method query_cs(Str $charm, Str $series = "trusty") {
     my $cs_url = 'https://manage.jujucharms.com/api/3/charm';
 
     my $composed_url = sprintf("%s/%s/%s", $cs_url, $series, $charm);
@@ -23,6 +22,7 @@ method query_cs($charm, $series = "trusty") {
     return decode_json($res->{content});
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -37,7 +37,7 @@ Juju::Util - helper methods for Juju
 
 =head1 VERSION
 
-version 2.0
+version 2.001_1
 
 =head1 SYNOPSIS
 
